#!/bin/bash

SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
. $SCRIPT_DIR/common.sh "$@"


echo "-- PROVISIONNING INFORMATION ---------------------------------------------------"
echo "VM name : $NODE_NAME"

if [[ $IS_MASTER == 1 ]]; then
    echo "VM is master"

fi
if [[ $IS_SLAVE == 1 ]]; then
    echo "VM is slave $SLAVE_NUMBER"
    echo "Master IP is $MASTER_IP"
fi

echo "IP address is $IP_ADDRESS"

echo "-- BASIC SETUP -----------------------------------------------------------------"

echo " - Updating the packages" 
sudo apt-get update > /tmp/setup_log 2>&1
fail_if_error $? "/tmp/setup_log" -1

echo " - Upgrading the appliance" 
sudo apt-get -y upgrade > /tmp/setup_log 2>&1
fail_if_error $? "/tmp/setup_log" -1

echo " - Installing a few utility tools"
sudo apt-get install -y tar wget git unzip curl > /tmp/setup_log 2>&1
fail_if_error $? "/tmp/setup_log" -1

echo " - Installing the latest OpenJDK"
sudo apt-get install -y openjdk-8-jdk > /tmp/setup_log 2>&1
fail_if_error $? "/tmp/setup_log" -1

echo " - Installing build tools"
sudo apt-get install -y build-essential autoconf libtool > /tmp/setup_log 2>&1
fail_if_error $? "/tmp/setup_log" -1

echo " - Installing swapspace"
sudo apt-get install -y swapspace > /tmp/setup_log 2>&1
fail_if_error $? "/tmp/setup_log" -1

echo " - Installing python"
sudo apt-get -y install  python-dev python-six python-virtualenv python-pip > /tmp/setup_log 2>&1
fail_if_error $? "/tmp/setup_log" -1

echo " - Installing other Mesos dependencies"
sudo apt-get -y install  libcurl4-nss-dev libsasl2-dev libsasl2-modules maven libapr1-dev libsvn-dev zlib1g-dev > /tmp/setup_log 2>&1
fail_if_error $? "/tmp/setup_log" -1

echo " - Installing Spark Dependency : Scala"
sudo apt-get -y install scala > /tmp/setup_log 2>&1
fail_if_error $? "/tmp/setup_log" -1

if [[ $IS_MASTER == 1 ]]; then
	echo " - Installing Zookeeper with apt (using plain debian package) "
	sudo apt-get -y install  zookeeper zookeeperd > /tmp/setup_log 2>&1
	fail_if_error $? "/tmp/setup_log" -1
fi

echo " - Installing ntp"
sudo apt-get -y install ntp > /tmp/setup_log 2>&1
fail_if_error $? "/tmp/setup_log" -1


echo " - Disabling IPv6"
sudo bash -c 'echo -e "\nnet.ipv6.conf.all.disable_ipv6=1" >>  /etc/sysctl.conf'
sudo bash -c 'echo -e "net.ipv6.conf.default.disable_ipv6=1" >>  /etc/sysctl.conf'
sudo bash -c 'echo -e "net.ipv6.conf.lo.disable_ipv6=1" >>  /etc/sysctl.conf'
sudo bash -c 'echo -e "net.ipv6.conf.eth0.disable_ipv6=1" >>  /etc/sysctl.conf'
sudo bash -c 'echo -e "net.ipv6.conf.eth1.disable_ipv6=1" >>  /etc/sysctl.conf'

sudo sysctl -w net.ipv6.conf.all.disable_ipv6=1  > /tmp/setup_log 2>&1
fail_if_error $? "/tmp/setup_log" -1

sudo sysctl -w net.ipv6.conf.default.disable_ipv6=1  > /tmp/setup_log 2>&1
fail_if_error $? "/tmp/setup_log" -1

sudo sysctl -w net.ipv6.conf.lo.disable_ipv6=1  > /tmp/setup_log 2>&1
fail_if_error $? "/tmp/setup_log" -1

sudo sysctl -w net.ipv6.conf.eth0.disable_ipv6=1  > /tmp/setup_log 2>&1
fail_if_error $? "/tmp/setup_log" -1

echo " - Creating test user: mes"
sudo groupadd mes
sudo useradd -g mes -G cdrom,floppy,sudo,audio,dip,video,plugdev,netdev -s /bin/bash mes 
sudo mkdir /home/mes
sudo cp /home/vagrant/.bashrc /home/mes/.bashrc
sudo cp /home/vagrant/.profile /home/mes/.profile
sudo chown -R mes.mes /home/mes
# setting password
sudo bash -c 'echo mes:mespwd | chpasswd'
# setting default shell

echo " - Adding user mes to sudoers"
sudo bash -c 'echo "mes ALL=(ALL) NOPASSWD:ALL" > /etc/sudoers.d/mes'
sudo chmod 440 /etc/sudoers.d/mes


# Call individual install scripts

# ES Stack
bash $SCRIPT_DIR/installElasticSearch.sh "$@"
if [[ $? != 0 ]]; then exit -14; fi

if [[ $IS_MASTER == 1 ]]; then

    bash $SCRIPT_DIR/installLogstash.sh "$@"
    if [[ $? != 0 ]]; then exit -15; fi    

    bash $SCRIPT_DIR/installKibana.sh "$@"
    if [[ $? != 0 ]]; then exit -16; fi

    bash $SCRIPT_DIR/installCerebro.sh "$@"
    if [[ $? != 0 ]]; then exit -17; fi    
fi

# Mesos / Spark
bash $SCRIPT_DIR/installMesos.sh "$@"
if [[ $? != 0 ]]; then exit -18; fi

bash $SCRIPT_DIR/installSpark.sh "$@"
if [[ $? != 0 ]]; then exit -19; fi

bash $SCRIPT_DIR/installESHadoop.sh "$@"
if [[ $? != 0 ]]; then exit -20; fi


# Call individual setup scripts

bash $SCRIPT_DIR/setupNTP.sh "$@"
if [[ $? != 0 ]]; then exit -21; fi

if [[ $IS_MASTER == 1 ]]; then

    bash $SCRIPT_DIR/setupZookeeper.sh "$@"
    if [[ $? != 0 ]]; then exit -22; fi
fi

# ES Stack
bash $SCRIPT_DIR/setupElasticSearch.sh "$@"
if [[ $? != 0 ]]; then exit -23; fi

if [[ $IS_MASTER == 1 ]]; then

    bash $SCRIPT_DIR/setupLogstash.sh "$@"
    if [[ $? != 0 ]]; then exit -24; fi    

    bash $SCRIPT_DIR/setupKibana.sh "$@"
    if [[ $? != 0 ]]; then exit -25; fi

    bash $SCRIPT_DIR/setupCerebro.sh "$@"
    if [[ $? != 0 ]]; then exit -26; fi    
fi

bash $SCRIPT_DIR/setupMesos.sh "$@"
if [[ $? != 0 ]]; then exit -27; fi

bash $SCRIPT_DIR/setupSpark.sh "$@"
if [[ $? != 0 ]]; then exit -28; fi

# XXX Dynamic Allocation seemed to mess up with ES-hadoop behaviour when using Spark 2.2 and ES-Hadoop 5.x
# XXX But happily it's Fixed with ES-Hadoop 6.0.x !
# Setup Spark Dynamic Allocation
bash $SCRIPT_DIR/setupSparkDynamicAllocation.sh "$@"
if [[ $? != 0 ]]; then exit -28; fi


echo " - Generating /etc/hosts for proper DNS resolution"
# TODO FIXME Remove hardcoding of IPs and make them configurable at Provisionning level
echo " - !! TODO : remove hardcoding of IPs and make them configurable at Provisionning level !!"
sudo bash -c 'echo -e "192.168.10.10\tmes_master" >>  /etc/hosts'
sudo bash -c 'echo -e "192.168.10.11\tmes_node1" >>  /etc/hosts'
sudo bash -c 'echo -e "192.168.10.12\tmes_node2" >>  /etc/hosts'

# This should be done really just before restart
echo " - Changing hostname - THIS REQUIRES REBOOT"
sudo bash -c "echo $NODE_NAME > /etc/hostname"
get_ip_address
sudo sed -i s/"127.0.1.1\tstretch.localdomain\tstretch"/"$IP_ADDRESS\t$NODE_NAME.localdomain"/g /etc/hosts
echo " -> Hostname changed successfully => PLEASE REBOOT VM ASAP !"





