#!/bin/bash


function fail_if_error(){
    if [[ $1 != 0 ]]; then
		echo " -> failed !!"
		cat $2
		exit $3
    fi
}

SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
SAVED_DIR=`pwd`


echo -e "\n0. HOST SYSTEM SANITY CHECKS"
echo "===============================================================================\n"

export IS_DEBIAN=0
export IS_REDHAT=0
if [[ -f "/etc/debian_version" ]]; then
    echo " - This is debian based distro"
    export IS_DEBIAN=1
elif [[ -f "/etc/redhat-release" ]]; then
    echo " - This is RedHat based distro"
    export IS_REDHAT=1
else
    echo " - This is an unknown distro"
    echo " - Unable to procees with sanity checks and automatic setup of the cluster. Please use vagrant commant in vagrant folder to build the 3 VMs"
    exit -1
fi

echo "- Checking is virtualbox is installed"

if [[ $IS_DEBIAN == 1 ]]; then
    if [[ `dpkg-query -l '*virtualbox*' | grep ii` == "" ]]; then
        echo "This setup requires VirtualBox installed and ready on the host machine"
        exit -2
    fi
fi
if [[ $IS_REDHAT == 1 ]]; then
    if [[ `rpm -qa | grep 'virtualbox'` == "" ]]; then
        echo "This setup requires VirtualBox installed and ready on the host machine"
        exit -2
    fi
fi

echo "- Checking is vagrant is installed"

if [[ $IS_DEBIAN == 1 ]]; then
    if [[ `dpkg-query -l '*vagrant' | grep ii` == "" ]]; then
        echo "This setup requires VirtualBox installed and ready on the host machine"
        exit -2
    fi
fi
if [[ $IS_REDHAT == 1 ]]; then
    if [[ `rpm -qa | grep 'vagrant'` == "" ]]; then
        echo "This setup requires Vagrant installed and ready on the host machine"
        exit -2
    fi
fi

echo -e "\n1. DELETING PREVIOUS VMS (if exist)"
echo "===============================================================================\n"

cd $SCRIPT_DIR/vagrant
vagrant destroy -f mes_master > /dev/null 2>&1
vagrant destroy -f mes_node1 > /dev/null 2>&1
vagrant destroy -f mes_node2 > /dev/null 2>&1


echo -e "\n2. BUILDING ELK-MS CLUSTER VMs"
echo "===============================================================================\n"

# Any subsequent(*) commands which fail will cause the shell script to exit immediately
set -e

echo -e "\n1.1 BUILDING mes_master VM"
vagrant up mes_master 

echo -e "\n1.2 BUILDING mes_node1 VM"
vagrant up mes_node1

echo -e "\n1.3 BUILDING mes_node2 VM"
vagrant up mes_node2

set +e

echo -e "\n3. ELK-MS CLUSTER SANITY CHECKS"
echo "===============================================================================\n"

echo -e "\n(TODO To Be Implemented)"

cd $SAVED_DIR
