#!/bin/bash


function fail_if_error(){
    if [[ $1 != 0 ]]; then
		echo " -> failed !!"
		cat $2
		exit $3
    fi
}

SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
SAVED_DIR=`pwd`

cd $SCRIPT_DIR/vagrant

echo "Starting Cluster"

echo "1.1 Checking mes_master VM ..."
vagrant status mes_master > /tmp/start_mes_master.log 2>&1
if [[ $? != 0 ]]; then
    echo "!!! mes_master VM doesn't seem to exist !!!"
    echo "Check vagrant logs below : "
    cat /tmp/start_mes_master.log
    exit -1
fi
if [[ `vagrant status mes_master 2>&1 | grep "not created"` != "" ]]; then
    echo "!!! mes_master VM doesn't seem to be set up already !!!"
    echo "Check vagrant logs below : "
    cat /tmp/start_mes_master.log
    echo "You may want to use setup.sh script to setup the cluster"
    exit -10
fi

echo "1.2 Checking mes_node1 VM ..."
vagrant status mes_node1 > /tmp/start_mes_node1.log 2>&1
if [[ $? != 0 ]]; then
    echo "!!! mes_node1 VM doesn't seem to exist !!!"
    echo "Check vagrant logs below : "
    cat /tmp/start_mes_node1.log
    exit -2
fi
if [[ `vagrant status mes_node1 2>&1 | grep "not created"` != "" ]]; then
    echo "!!! mes_node1 VM doesn't seem to be set up already !!!"
    echo "Check vagrant logs below : "
    cat /tmp/start_mes_node1.log
    echo "You may want to use setup.sh script to setup the cluster"
    exit -20
fi

echo "1.3 Checking mes_node2 VM ..."
vagrant status mes_node2 > /tmp/start_mes_node2.log 2>&1
if [[ $? != 0 ]]; then
    echo "!!! mes_node2 VM doesn't seem to exist !!!"
    echo "Check vagrant logs below : "
    cat /tmp/start_mes_node2.log
    exit -3
fi
if [[ `vagrant status mes_node2 2>&1 | grep "not created"` != "" ]]; then
    echo "!!! mes_node2 VM doesn't seem to be set up already !!!"
    echo "Check vagrant logs below : "
    cat /tmp/start_mes_node2.log
    echo "You may want to use setup.sh script to setup the cluster"
    exit -20
fi


echo "2.1 Starting mes_master VM"
vagrant up mes_master > /tmp/start_mes_master.log 2>&1
fail_if_error $? "/tmp/start_mes_master.log" -1
echo " -> mes_master started"

echo "2.2 Starting mes_node1 VM"
vagrant up mes_node1 > /tmp/start_mes_node1.log 2>&1
fail_if_error $? "/tmp/start_mes_node1.log" -1
echo " -> mes_node1 started"

echo "2.3 Starting mes_node2 VM"
vagrant up mes_node2 > /tmp/start_mes_node2.log 2>&1
fail_if_error $? "/tmp/start_mes_node2.log" -1
echo " -> mes_node2 started"


cd $SAVED_DIR
